@@ -2,15 +2,16 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from authlib.base_user import BaseUser
+from authlib.roles import RoleField
 
 
 def _obfuscate(email):
     user, _sep, domain = email.partition("@")
+    keep = 3
     return (
-        "%s%s@***.%s"
-        % (
-            user[:3],
-            "***" if len(user) > 3 else "",
+        "{}{}@***.{}".format(
+            user[:keep],
+            "***" if len(user) > keep else "",
             domain.rsplit(".", 1)[-1],
         )
         if domain
@@ -20,6 +21,7 @@ def _obfuscate(email):
 
 class User(BaseUser):
     full_name = models.CharField(_("full name"), max_length=200)
+    role = RoleField()
 
     class Meta(BaseUser.Meta):
         ordering = ["full_name"]
